@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.011';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.012';
 use 5.010; use strict; use warnings;
 
 use Carp;
@@ -276,7 +276,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -389,7 +389,7 @@ Example:
 
 If the C<$dir> argument is relative, then it will be appended to the
 C<file_root> setting in the configuration file. If C<file_root> is not set
-in the configuration file, C<lib/data/markdown_files> is used.
+in the configuration file, the default C<lib/data/markdown_files> is used.
 
 Each file can be thought of as a chapter within a single larger document
 comprised of all the individual files. Ideally, each file will have a single
@@ -487,16 +487,16 @@ converted.
 =head1 CONFIGURATION
 
 Though the C<mdfile_2html> and C<mdfile_2html> keywords can be passed arguments
-directly, the configuration is a more convenient way to associate routes with
-the HTML generatd by the converted markdown files. This makes it very easy to
-generate new pages on your website. Unless you need to modify the output of the
-HTML generated by this module in some way, we recommend using the configuration
-file to generate the pages.
+directly, modifying the Dancer2 C<config.yml> file to associate routes with the
+HTML generatd by the converted markdown files to makes it exceedingly easy to
+add pages to your website. Unless you need to modify the output of the HTML
+generated by this module in some way, using the configuration file is the
+preferred method.
 
 All of the options listed above are supported by the configuration file.
 
-The configuration settings are placed in the C<config.yml> file usually located
-in the root of your Dancer2 app and begins with:
+Configure the C<config.yml> file, usually located in the root of your Dancer2 app,
+as follows:
 
   plugins:
     MarkdownFiletoHTML:
@@ -519,12 +519,11 @@ After the defaults, you can list your routes:
          - another_web_page:
            file: '/convert/this/file/with/absolute/path.md'
 
-Routes must have either a C<dir> or C<file> property. Relative paths are
-relative to the C<file_root> default.
+Routes must have either a C<dir> or C<file> property. Paths can be absolute or
+relative. Relative paths are appended to the path in C<file_root>.
 
 The default options can be overridden for each route like so:
 
-       routes:
          - my_page
            file: 'file.md'
            toc: 0
@@ -535,7 +534,6 @@ Consult the L<#Options> section for defaults for each of the options.
 The options that apply to directories accept a list of arguments, created like
 this:
 
-        routes:
           - another_page:
             dir: 'my_dir_containing_md_file'
             include_files:
